@@ -16,7 +16,6 @@ class TransferError(Exception):
 
 
 class FileTooLarge(TransferError):
-	"""Base video unavailable error."""
 	def __init__(self, limit: int):
 		"""
 		:param int limit:
@@ -32,3 +31,27 @@ class FileTooLarge(TransferError):
 	@property
 	def limit(self):
 		return str(round(self._limit/(1024*1024*1024), 2))+'GB' if len(str(self._limit//(1024*1024))) >= 4 else str(round(self._limit/(1024*1024), 2))+'MB'
+
+class PrepareError(TransferError):
+	def __init__(self):
+		"""
+		:param int limit:
+			Max uploading size.
+		"""
+		super().__init__(self.error_message)
+
+	@property
+	def error_message(self):
+		return f'Unable to fetch prepare data from site try --force.'
+
+class EmptyFileError(TransferError):
+	def __init__(self):
+		"""
+		:param int limit:
+			Max uploading size.
+		"""
+		super().__init__(self.error_message)
+
+	@property
+	def error_message(self):
+		return f'Could not upload empty file.'
\ No newline at end of file
